==> nextcloud-20.0.12.tgz: nextcloud/apps/user_status/l10n/ar.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "آخر الحالات",
    "In a meeting" : "في اجتماع",
    "Commuting" : "تجوال",
    "Out sick" : "مريض",
    "Vacationing" : "في اجازة",
    "Working remotely" : "العمل عن بعد",
    "User status" : "حالة العضو",
    "Clear status message after" : "احذف الحالة بعد",
    "What's your status?" : "ماهي حالتك؟",
    "Set status" : "تعيين الحالة",
    "Online status" : "حالة الاتصال",
    "Status message" : "رسالة الحالة",
    "Clear status message" : "حذف رسالة الحالة",
    "Set status message" : "تعيين رسالة الحالة",
    "There was an error saving the status" : "حدث خطأ اثناء حفظ الحالة",
    "There was an error clearing the status" : "حدث خطأ اثناء حذف الحالة",
    "No recent status changes" : "لم يتم تغيير الحالة",
    "Away" : "بالخارج",
    "Do not disturb" : "عدم الازعاج",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "غير محدد",
    "Today" : "اليوم",
    "This week" : "هذا الأسبوع",
    "Online" : "متصل",
    "Invisible" : "عدم الظهور",
    "Offline" : "غير متصل",
    "There was an error saving the new status" : "حدث خطأ اثناء حفظ الحالة الجديدة",
    "30 minutes" : "30 دقيقة",
    "1 hour" : "1 ساعة",
    "4 hours" : "4 ساعات",
    "Mute all notifications" : "عدم اظهار جميع التنبيهات",
    "Appear offline" : "الحالة غير متصل",
    "Clear status after" : "مسح رسالة الحالة بعد"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/user_status/l10n/ar.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "آخر الحالات",
    "In a meeting" : "في اجتماع",
    "Commuting" : "تجوال",
    "Out sick" : "مريض",
    "Vacationing" : "في اجازة",
    "Working remotely" : "العمل عن بعد",
    "User status" : "حالة العضو",
    "Clear status message after" : "احذف الحالة بعد",
    "Set status" : "تعيين الحالة",
    "Online status" : "حالة الاتصال",
    "Status message" : "رسالة الحالة",
    "Clear status message" : "حذف رسالة الحالة",
    "Set status message" : "تعيين رسالة الحالة",
    "There was an error saving the status" : "حدث خطأ اثناء حفظ الحالة",
    "There was an error clearing the status" : "حدث خطأ اثناء حذف الحالة",
    "No recent status changes" : "لم يتم تغيير الحالة",
    "Away" : "بالخارج",
    "Do not disturb" : "عدم الازعاج",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "غير محدد",
    "Today" : "اليوم",
    "This week" : "هذا الأسبوع",
    "Online" : "متصل",
    "Invisible" : "عدم الظهور",
    "Offline" : "غير متصل",
    "There was an error saving the new status" : "حدث خطأ اثناء حفظ الحالة الجديدة",
    "30 minutes" : "30 دقيقة",
    "1 hour" : "1 ساعة",
    "4 hours" : "4 ساعات",
    "Mute all notifications" : "عدم اظهار جميع التنبيهات",
    "Appear offline" : "الحالة غير متصل",
    "Clear status after" : "مسح رسالة الحالة بعد",
    "What's your status?" : "ماهي حالتك؟"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
